==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/NetworkStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NetworkStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.NetworkStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.NetworkStatus,io.fabric8.openshift.api.model.operator.v1.NetworkStatusBuilder>{
  public NetworkStatusBuilder() {
    this(false);
  }
  public NetworkStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new NetworkStatus(), validationEnabled);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NetworkStatus(), validationEnabled);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NetworkStatus instance) {
    this(fluent, instance, false);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NetworkStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatus instance) {
    this(instance,false);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.NetworkStatus build() {
    NetworkStatus buildable = new NetworkStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkStatusBuilder that = (NetworkStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/NetworkStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NetworkStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.NetworkStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.NetworkStatus,io.fabric8.openshift.api.model.operator.v1.NetworkStatusBuilder>{
  public NetworkStatusBuilder() {
    this(false);
  }
  public NetworkStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new NetworkStatus(), validationEnabled);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NetworkStatus(), validationEnabled);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NetworkStatus instance) {
    this(fluent, instance, false);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NetworkStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGenerations(instance.getGenerations()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatus instance) {
    this(instance,false);
  }
  public NetworkStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NetworkStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withGenerations(instance.getGenerations()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.NetworkStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.NetworkStatus build() {
    NetworkStatus buildable = new NetworkStatus(fluent.getConditions(),fluent.getGenerations(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkStatusBuilder that = (NetworkStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
